#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_UMINUS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_UMINUS_HPP_INCLUDED

#include <boost/simd/operator/include/functions/uminus.hpp>

#endif
